# exbw

Wrapper for bitwarden cli client.

Retrieve specified item field of bitwarden.
**NOTICE: Require Bitwarden CLI Installed**

## Install

`pip install exbw`

## Usage

- `ITEM` vault item name
- `FIELD` item field name (default: password)

`python3 -m exbw ITEM [-f FIELD]`
